using FurnitureAssemblyContracts.StoragesContracts;
using Microsoft.Extensions.DependencyInjection;
using FurnitureAssemFileImplement.Implements;
using FurnitureAssemblyBusinessLogic.BusinessLogics;
using FurnitureAssemblyContracts.BusinessLogicsContracts;
using ShopBusinessLogic.BusinessLogics;
using FurnitureAssemblyView;
using NLog.Extensions.Logging;
using Microsoft.Extensions.Logging;

namespace FurnitureAssembly
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<MainForm>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IFurnitureStorage, FurnitureStorage>();
            services.AddTransient<IShopStorage, ShopStorage>();
            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IfurnitureLogic, FurnitureLogic>();
            services.AddTransient<IShopLogic, ShopLogic>();
            services.AddTransient<MainForm>();
            services.AddTransient<ComponentForm>();
            services.AddTransient<ComponentsForm>();
            services.AddTransient<OrderForm>();
            services.AddTransient<FurnitureForm>();
            services.AddTransient<FurnituresForm>();
            services.AddTransient<FurnitureComponentForm>();
            services.AddTransient<FormShop>();
            services.AddTransient<FormShops>();
            services.AddTransient<FormAddToShop>();
            services.AddTransient<FormSell>();
        }


    }
}